@@ -1,6 +1,6 @@
 from .transform import Transform
 from .combinators import sequence, merge, map_tags
 from .workarounds import fileset
-from .context import BakerContext
+from .context import BakerDriverContext
 from .tag import InputTag, OutputTag
 from .cli import cli
\ No newline at end of file
