@@ -11,6 +11,7 @@ from ..exceptions import (
 from ..util import classproperty
 from ..workarounds import is_fileset
 from typeguard import typechecked
+from .base import CombinatorBase
 
 
 @typechecked
@@ -62,29 +63,39 @@ def _determine_sequence_interface(scope_diagram, exposed_intermediates):
 
 
 def _build_sequence_class(seq_input_tags, seq_output_tags, seq_steps, seq_name):
-    class Sequence(Transform):
+    class Sequence(CombinatorBase):
         nonlocal seq_input_tags, seq_output_tags, seq_steps, seq_name
+        # Hack to ensure we can pickle / unpickle these dynamic classes
+        __creation_values__ = (
+            _build_sequence_class,
+            seq_input_tags,
+            seq_output_tags,
+            seq_steps,
+            seq_name,
+        )
+
         input_tags = seq_input_tags
         output_tags = seq_output_tags
-        steps = seq_steps
+        substeps = seq_steps
         _name = seq_name
 
         def _generate_temp_filename(self, sid):
-            target_fs = self.context.fs_for_intermediates
-            return "{}://tinybaker-{}__{}".format(target_fs, sid, uuid4())
+            target_fs = self._current_worker_context.baker_config.fs_for_intermediates
+            target_path = self._current_worker_context.tmp_path
+            return f"{target_fs}://{target_path}/tinybaker-{sid}__{uuid4().hex}"
 
         @classmethod
         def structure(cls):
             struct = super(Sequence, cls).structure()
             struct["type"] = "sequence"
-            struct["steps"] = [step.structure() for step in cls.steps]
+            struct["steps"] = [step.structure() for step in cls.substeps]
             return struct
 
         @classproperty
         def name(cls):
             if cls._name:
                 return cls._name
-            return "Seq({})".format(",".join([step.name for step in cls.steps]))
+            return "Seq({})".format(",".join([step.name for step in cls.substeps]))
 
         def script(self):
             sequence_instance_id = uuid4()
@@ -99,7 +110,7 @@ def _build_sequence_class(seq_input_tags, seq_output_tags, seq_steps, seq_name):
             }
 
             lexical_scope = {}
-            for step in self.steps:
+            for step in self.substeps:
                 # Step input files
                 input_paths_from_sequence = {
                     tag: seq_input_paths[tag]
@@ -138,7 +149,6 @@ def _build_sequence_class(seq_input_tags, seq_output_tags, seq_steps, seq_name):
                     step(
                         input_paths=input_paths,
                         output_paths=output_paths,
-                        context=self.context,
                         overwrite=self.overwrite,
                     )
                 )
@@ -148,7 +158,7 @@ def _build_sequence_class(seq_input_tags, seq_output_tags, seq_steps, seq_name):
 
             # Phase 2: Run instances
             for instance in instances:
-                instance._exec_with_run_info(self._current_run_info)
+                self._current_worker_context.execute([instance])
 
     return Sequence
 
