@@ -1,6 +1,5 @@
-from fs import open_fs
 from typing import Dict, Set, Union, List, Iterable, Any
-from abc import ABC, abstractmethod
+from abc import abstractmethod
 from .fileref import FileRef
 from .workarounds import is_fileset
 from .exceptions import (
@@ -9,13 +8,14 @@ from .exceptions import (
     BakerError,
     SeriousErrorThatYouShouldOpenAnIssueForIfYouGet,
     ConfigurationError,
+    UnusedFileWarning,
 )
-from .context import BakerContext, get_default_context
+from .context import get_default_context
 from .util import get_files_in_path_dict, classproperty
 from typeguard import typechecked
 from .namespace_transforms import namespace_to_transform, dict_to_transform
 from .tag import InputTag, OutputTag, input_files_ctx, output_files_ctx
-
+from warnings import warn
 
 PathDict = Dict[str, Union[str, Iterable[str]]]
 FileDict = Dict[str, Union[FileRef, List[FileRef]]]
@@ -43,7 +43,7 @@ class Transform(metaclass=TransformMeta):
 
     :param input_paths: Dictionary of input tags to files.
     :param output_paths: Dictionary of output tags to files.
-    :param optional context: The BakerContext to use for this transformation
+    :param optional context: The BakerDriverContext to use for this transformation
     :param optional overwrite: Whether or not to configure the transformation to overwrite output files on execution
     """
 
@@ -68,12 +68,13 @@ class Transform(metaclass=TransformMeta):
         """
         return dict_to_transform(Transform, dic)
 
+    parallelism = 1
+
     @typechecked
     def __init__(
         self,
         input_paths: PathDict,
         output_paths: PathDict,
-        context: BakerContext = get_default_context(),
         overwrite: bool = False,
     ):
         _ensure_fileset_iff_fileset_tag(input_paths)
@@ -84,9 +85,8 @@ class Transform(metaclass=TransformMeta):
 
         self.input_files: FileDict = {}
         self.output_files: FileDict = {}
-        self.context = context
         self.overwrite = overwrite
-        self._current_run_info = None
+        self._current_worker_context = None
 
     @classproperty
     def input_tags(cls):
@@ -131,7 +131,7 @@ class Transform(metaclass=TransformMeta):
                             individual_path,
                             read_bit=True,
                             write_bit=False,
-                            run_info=self._current_run_info,
+                            worker_context=self._current_worker_context,
                         )
                     )
                 self.input_files[tag] = refset
@@ -140,7 +140,7 @@ class Transform(metaclass=TransformMeta):
                     input_paths[tag],
                     read_bit=True,
                     write_bit=False,
-                    run_info=self._current_run_info,
+                    worker_context=self._current_worker_context,
                 )
 
         for tag in output_paths:
@@ -152,7 +152,7 @@ class Transform(metaclass=TransformMeta):
                             individual_path,
                             read_bit=False,
                             write_bit=True,
-                            run_info=self._current_run_info,
+                            worker_context=self._current_worker_context,
                         )
                     )
                 self.output_files[tag] = refset
@@ -161,7 +161,7 @@ class Transform(metaclass=TransformMeta):
                     output_paths[tag],
                     read_bit=False,
                     write_bit=True,
-                    run_info=self._current_run_info,
+                    worker_context=self._current_worker_context,
                 )
 
     def _validate_file_existence(self):
@@ -225,26 +225,47 @@ class Transform(metaclass=TransformMeta):
         return cls.__name__
 
     def run(self):
-        """Run the transform instance"""
-        self.context.run_transform(self)
+        """Run the transform instance in the default context"""
+        get_default_context().run(self)
 
-    def _exec_with_run_info(self, run_info):
+    def _exec_with_worker_context(self, worker_context):
         # Set
         input_token = input_files_ctx.set(self.input_files)
         output_token = output_files_ctx.set(self.output_files)
         try:
-            self._current_run_info = run_info
+            self._current_worker_context = worker_context
             self._init_file_dicts(self.input_paths, self.output_paths)
             self._validate_file_existence()
-            if not run_info:
+            if not worker_context:
                 raise SeriousErrorThatYouShouldOpenAnIssueForIfYouGet(
-                    "No current run information, somehow!"
+                    "No current worker context, somehow!"
                 )
             self.script()
+            self._warn_if_files_untouched()
         finally:
             input_files_ctx.reset(input_token)
             output_files_ctx.reset(output_token)
 
+    # Only for leaf nodes!!
+    def _warn_if_files_untouched(self):
+        refs: List[FileRef] = []
+
+        def add_refs(ref_dict: Dict[str, FileRef]) -> None:
+            for tag in ref_dict:
+                if is_fileset(tag):
+                    refs.extend([(tag, ref) for ref in ref_dict[tag]])
+                else:
+                    refs.append((tag, ref_dict[tag]))
+
+        add_refs(self.input_files)
+        add_refs(self.output_files)
+        for tag, ref in refs:
+            if not ref.opened:
+                warn(
+                    "Unused file for tag {}: {}".format(tag, ref.path),
+                    UnusedFileWarning,
+                )
+
     @abstractmethod
     def script(self):
         """
