@@ -1,6 +1,13 @@
 FILESET_ANNOT = "fileset::"
 
 
+def get_annotation(tag):
+    if "::" in tag:
+        return tag.split("::")[0]
+    else:
+        return "file"
+
+
 def fileset(tag):
     if not is_fileset(tag):
         tag = FILESET_ANNOT + tag
